@@ -2,7 +2,7 @@
  *  arch-tag: Implementation of main song information display widget
  *
  *  Copyright (C) 2002, 2003 Jorn Baayen <jorn@nl.linux.org>
- *  Copyright (C) 2003 Colin Walters <cwalters@gnome.org>
+ *  Copyright (C) 2003 Colin Walters <walters@gnome.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -34,10 +34,11 @@
 
 #include "rb-song-display-box.h"
 #include "rb-stock-icons.h"
-#include "rb-link.h"
 #include "rb-player.h"
 #include "rb-debug.h"
 #include "rb-ellipsizing-label.h"
+#include "rb-preferences.h"
+#include "eel-gconf-extensions.h"
 
 static void rb_player_class_init (RBPlayerClass *klass);
 static void rb_player_init (RBPlayer *player);
@@ -98,7 +99,7 @@ struct RBPlayerPrivate
 	GtkWidget *urlframe;
 	GtkWidget *urlline;
 	gboolean urlline_shown;
-	RBLink *url;
+	GnomeHRef *url;
 
 	guint timeout;
 	
@@ -221,13 +222,13 @@ rb_player_init (RBPlayer *player)
 	 *           GtkHBox		(priv->textframe)
 	 *	       RBSongDisplayBox (priv->displaybox)
 	 *               GtkLabel	("from")
-	 *               RBLink		(priv->displaybox->album)
+	 *               GnomeHRef	(priv->displaybox->album)
 	 *               GtkLabel	("by")
-	 *               RBLink		(priv->displaybox->artist)
+	 *               GnomeHRef	(priv->displaybox->artist)
 	 *           GtkHBox		(priv->urlframe)
 	 *	       GtkHBox		(priv->urlline)
 	 *               GtkLabel	("Listening to")
-	 *               RBLink		(priv->url)
+	 *               GnomeHRef	(priv->url)
 	 *   GtkAlignment		(priv->timeframe)
 	 *     GtkVBox			(priv->timeline)
 	 *       GtkHScale		(priv->scale)
@@ -278,7 +279,7 @@ rb_player_init (RBPlayer *player)
 
 	label = gtk_label_new (_("Listening to "));
 	gtk_box_pack_start (GTK_BOX (urlline), GTK_WIDGET (label), FALSE, TRUE, 0);
-	player->priv->url = rb_link_new();
+	player->priv->url = (GnomeHRef *) gnome_href_new ("", "");
 	gtk_box_pack_start (GTK_BOX (urlline), GTK_WIDGET (player->priv->url), FALSE, TRUE, 0);
 	player->priv->urlline_shown = FALSE;
 
@@ -502,8 +503,11 @@ rb_player_sync (RBPlayer *player)
 				*tmp = '|';
 			tmp = ALBUM_INFO_URL (s);
 			g_free (s);
-			rb_link_set (player->priv->displaybox->album, album,
-				     _("Get information on this album from the web"), tmp);
+
+			gnome_href_set_url (player->priv->displaybox->album, tmp);
+			escaped = g_markup_escape_text (album, -1);
+			gnome_href_set_text (player->priv->displaybox->album, escaped);
+			g_free (escaped);
 			g_free (tmp);
 
 			s = tmp = g_strdup (artist);
@@ -513,8 +517,10 @@ rb_player_sync (RBPlayer *player)
 			}
 			tmp = ARTIST_INFO_URL (s);
 			g_free (s);
-			rb_link_set (player->priv->displaybox->artist, artist,
-				     _("Get information on this artist from the web"), tmp);
+			gnome_href_set_url (player->priv->displaybox->artist, tmp);
+			escaped = g_markup_escape_text (artist, -1);
+			gnome_href_set_text (player->priv->displaybox->artist, escaped);
+			g_free (escaped);
 			g_free (tmp);
 		}
 
@@ -523,9 +529,8 @@ rb_player_sync (RBPlayer *player)
 			g_return_if_fail (player->priv->urltext != NULL);
 			rb_debug ("urlline shown, urltext: %s urllink: %s",
 				  player->priv->urltext, player->priv->urllink);
-			rb_link_set (player->priv->url, player->priv->urltext,
-				     _("Get more information on this station from the web"),
-				     player->priv->urllink);
+			gnome_href_set_url (player->priv->url, player->priv->urllink);
+			gnome_href_set_text (player->priv->url, player->priv->urltext);
 		}
 
 		rb_player_set_show_timeline (player, have_duration);
@@ -796,7 +801,16 @@ rb_player_get_elapsed_string (RBPlayer *player)
 	if (player->priv->state->duration > 0) {
 		minutes2 = player->priv->state->duration / 60;
 		seconds2 = player->priv->state->duration % 60;
-		return g_strdup_printf (_("%d:%02d of %d:%02d"), minutes, seconds, minutes2, seconds2);
+		if (eel_gconf_get_boolean (CONF_UI_TIME_DISPLAY)) {
+			return g_strdup_printf (_("%d:%02d of %d:%02d"), minutes, seconds, minutes2, seconds2);
+		} else {
+			int remaining = player->priv->state->duration - elapsed;
+			int remaining_minutes = remaining / 60;
+			// remaining could conceivably be negative. This would be a bug,
+			// but the elapsed time will display right with the abs().
+			int remaining_seconds = abs (remaining % 60);
+			return g_strdup_printf (_("%d:%02d of %d:%02d remaining"), remaining_minutes, remaining_seconds, minutes2, seconds2);
+		}
 	} else {
 		return g_strdup_printf (_("%d:%02d"), minutes, seconds);
 	}
